@@ -905,8 +905,8 @@ gint			parse_language_section(gchar *buffer,
 	  Prefs.L[Lg].Extensions[0] = ' ';
 	  for (j = 0; buffer[i + j] != '\n'; j++)
 	      Prefs.L[Lg].Extensions[1 + j] = buffer[i + j];
-	  Prefs.L[Lg].Extensions[j] = ' ';
-	  Prefs.L[Lg].Extensions[j + 1] = '\0';
+	  Prefs.L[Lg].Extensions[j + 1] = ' ';
+	  Prefs.L[Lg].Extensions[j + 2] = '\0';
 	  i += j;
 #ifdef DEBUG_WORDFILE
 	  g_print(__FILE__": %s(): File Extensions = \"%s\"\n", __func__,
