@@ -182,7 +182,7 @@ void menu_items_treatment (GtkWidget *Widget, guint Op)
 	  change_case (4);
 	  print_msg ("Case inverted...");
 	}
-      break; 
+      break;
     case UNIX_DOS             :
       if ((OpenedFilesCnt) && !FPROPS(CurrentPage, ReadOnly))
 	{
@@ -219,6 +219,24 @@ void menu_items_treatment (GtkWidget *Widget, guint Op)
 	  conv_mac_to_unix ();
 	}
       break;
+    case UNIX_DOS_ALL             :
+      convert_all(conv_unix_to_dos);
+      break;
+    case UNIX_MAC_ALL             :
+      convert_all(conv_unix_to_mac);
+      break;
+    case DOS_UNIX_ALL             :
+      convert_all(conv_dos_to_unix);
+      break;
+    case DOS_MAC_ALL              :
+      convert_all(conv_dos_to_mac);
+      break;
+    case MAC_DOS_ALL              :
+      convert_all(conv_mac_to_dos);
+      break;
+    case MAC_UNIX_ALL             :
+      convert_all(conv_mac_to_unix);
+      break;
     case FILE_INFO            : file_info (CurrentPage);       break;
     case TOOLBAR              :
       if ((!ToolBarToggleDisplay) && (TOOLBAR_DISPLAY))
@@ -321,6 +339,7 @@ void menu_items_treatment (GtkWidget *Widget, guint Op)
       break;
     case ABOUT                : about ();                      break;
     }
+  (void)Widget; /* avoid the "unused parameter" warning */
 }
 
 
@@ -349,7 +368,7 @@ static GtkItemFactoryEntry MenuEntries[] = {
   {"/Edit/_Copy", "<control>C", menu_items_treatment, COPY, "<Item>"},
   {"/Edit/_Paste", "<control>V", menu_items_treatment, PASTE, "<Item>"},
   {"/Edit/C_lear", NULL, menu_items_treatment, CLEAR, "<Item>"},
-  {"/Edit/_Select All", NULL, menu_items_treatment, SELECT_ALL, "<Item>"},
+  {"/Edit/_Select All", "<control>A", menu_items_treatment, SELECT_ALL, "<Item>"},
   {"/Edit/Co_mplete", "<alt>space", menu_items_treatment, COMPLETE, "<Item>"},
   {"/Edit/sep", NULL, NULL, 0, "<Separator>"},
   {"/Edit/Toggle _Readonly", NULL, menu_items_treatment, READONLY, "<Item>"},
@@ -374,6 +393,20 @@ static GtkItemFactoryEntry MenuEntries[] = {
    MAC_DOS, "<Item>"},
   {"/Tools/Conversions/MAC to UNIX", NULL, menu_items_treatment,
    MAC_UNIX, "<Item>"},
+  {"/_Tools/_Conversions (All)/UNIX to DOS", NULL, menu_items_treatment,
+   UNIX_DOS_ALL, "<Item>"},
+  {"/Tools/Conversions (All)/UNIX to MAC", NULL, menu_items_treatment,
+   UNIX_MAC_ALL, "<Item>"},
+  {"/Tools/Conversions (All)/sep", NULL, NULL, 0, "<Separator>"},
+  {"/Tools/Conversions (All)/DOS to UNIX", NULL, menu_items_treatment,
+   DOS_UNIX_ALL, "<Item>"},
+  {"/Tools/Conversions (All)/DOS to MAC", NULL, menu_items_treatment,
+   DOS_MAC_ALL, "<Item>"},
+  {"/Tools/Conversions (All)/sep", NULL, NULL, 0, "<Separator>"},
+  {"/Tools/Conversions (All)/MAC to DOS", NULL, menu_items_treatment,
+   MAC_DOS_ALL, "<Item>"},
+  {"/Tools/Conversions (All)/MAC to UNIX", NULL, menu_items_treatment,
+   MAC_UNIX_ALL, "<Item>"},
   {"/Tools/sep", NULL, NULL, 0, "<Separator>"},
   {"/_Tools/_Base Converter", NULL, menu_items_treatment, CONVERTER, "<Item>"},
   {"/_Tools/_Color Picker", NULL, menu_items_treatment, COLOR, "<Item>"},
@@ -613,7 +646,7 @@ void add_page_in_notebook (GtkNotebook *Notebook, gchar *FileName)
 				       GTK_CORNER_TOP_LEFT);
   FPROPS(OpenedFilesCnt, Text) = gtk_text_new (NULL, NULL);
   Style = gtk_style_copy (gtk_widget_get_style(FPROPS(OpenedFilesCnt, Text)));
-  Style -> font = gdk_font_load (FONT);
+  Style -> font = gdk_fontset_load (FONT);
   Style -> bg[GTK_STATE_SELECTED].red = SELECTED_BG_RED;
   Style -> bg[GTK_STATE_SELECTED].green = SELECTED_BG_GREEN;
   Style -> bg[GTK_STATE_SELECTED].blue = SELECTED_BG_BLUE;
@@ -734,6 +767,8 @@ void set_title (GtkNotebook *Notebook, GtkNotebookPage *Page,
 			      (FPROPS(CurrentPage, Name), " - ",
 			       APP_NAME, " ", VERSION_NUMBER, NULL)));
   g_free (Title);
+  (void)Notebook; /* avoid the "unused parameter" warning */
+  (void)Page; /* avoid the "unused parameter" warning */
 }
 
 
@@ -810,6 +845,8 @@ void interface (gint argc, gchar *argv[])
   gtk_box_pack_start (GTK_BOX(VBox), HandleBox, FALSE, FALSE, 0);
   init_toolbar (GTK_BOX(VBox));
   MainNotebook = gtk_notebook_new ();
+  read_uedit_wordfile (WORDFILE);
+  editor_init();
   MenuBar = menubar_new (MainWindow);
   gtk_container_add (GTK_CONTAINER(HandleBox), MenuBar);
   gtk_notebook_popup_enable (GTK_NOTEBOOK(MainNotebook));
@@ -820,7 +857,6 @@ void interface (gint argc, gchar *argv[])
 		      (GtkSignalFunc) set_title, NULL);
   init_msgbar (GTK_BOX(VBox));
   print_msg ("You're the welcome...");
-  read_uedit_wordfile (WORDFILE);
   command_line (argc, argv);
   autosave (AUTOSAVE_DELAY);
   gtk_widget_show_all (MainWindow);
