@@ -150,6 +150,7 @@ void set_preferences_to_disk (t_settings *set, t_colors *col)
       set_bool_conf ("General/Adv/AutoIndent", set -> auto_indent);
       set_bool_conf ("General/Adv/AutoCorrect", set -> auto_correct);
     }
+  (void)col; /* avoid the "unused parameter" warning */
 }
 
 
@@ -191,7 +192,7 @@ gboolean text_preview (GtkWidget *Widget)
   GtkStyle *Style;
 
   Style = gtk_style_copy (gtk_widget_get_style(Widget));
-  Style -> font = gdk_font_load (set_temp.font);
+  Style -> font = gdk_fontset_load (set_temp.font);
   Style -> bg[GTK_STATE_SELECTED].red = set_temp.selected_bg[0];
   Style -> bg[GTK_STATE_SELECTED].green = set_temp.selected_bg[1];
   Style -> bg[GTK_STATE_SELECTED].blue = set_temp.selected_bg[2];
@@ -244,7 +245,7 @@ void apply_changes (GtkWidget *Widget, t_settings *set)
 
       Style = gtk_style_copy
 	(gtk_widget_get_style(FPROPS(0, Text)));
-      Style -> font = gdk_font_load (set -> font);
+      Style -> font = gdk_fontset_load (set -> font);
       Style -> bg[GTK_STATE_SELECTED].red = set -> selected_bg[0];
       Style -> bg[GTK_STATE_SELECTED].green = set -> selected_bg[1];
       Style -> bg[GTK_STATE_SELECTED].blue = set -> selected_bg[2];
@@ -281,6 +282,7 @@ void apply_changes (GtkWidget *Widget, t_settings *set)
 	for (i = 0; i < OpenedFilesCnt; i++)
 	  gtk_text_set_word_wrap (GTK_TEXT(FPROPS(i, Text)), FALSE);
     }
+  (void)Widget; /* avoid the "unused parameter" warning */
   print_msg ("Preferences saved...");
 }
 
