@@ -331,6 +331,17 @@ void refresh_search (GtkWidget *Widget, gchar *Data)
 	  SearchPrefs -> RepAll = FALSE;
 	}
     }
+  else if (!strcmp (Data, "rep_all_buffers"))
+    {
+      if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(Widget)))
+	{
+	  SearchPrefs -> RepAllBuffers = TRUE;
+	}
+      else
+	{
+	  SearchPrefs -> RepAllBuffers = FALSE;
+	}
+    }
   else if (!strcmp (Data, "replace"))
     {
       gchar *ReplaceString;
@@ -352,7 +363,41 @@ void refresh_search (GtkWidget *Widget, gchar *Data)
 	  (GTK_EDITABLE(FPROPS(CurrentPage, Text)));
       else
 	SearchBegin = 0;
-      if (SearchPrefs -> RepAll)
+      if (SearchPrefs -> RepAllBuffers)
+	{
+	  gchar *msg;
+	  gint i;
+	  gint rep_nb = 0;
+	  for (i = 0; i < OpenedFilesCnt; i++)
+	    {
+	      if (!FPROPS(CurrentPage, ReadOnly))
+		{
+		  gtk_notebook_set_page (GTK_NOTEBOOK(MainNotebook), i);
+		  rep_nb += replace_all (i,
+					 SearchPrefs -> CaseSen,
+					 SearchPrefs -> RegExp,
+					 (i == CurrentPage) ? SearchBegin : 0,
+					 SearchPrefs -> StringToSearch,
+					 ReplaceString);
+		}
+	    }
+	  gtk_notebook_set_page (GTK_NOTEBOOK(MainNotebook), CurrentPage);
+	  if (rep_nb == 0)
+	    msg = g_strdup_printf
+	      ("The string \"%s\" hasn't been found...",
+	       SearchPrefs -> StringToSearch);
+	  else if (rep_nb == 1)
+	    msg = g_strdup_printf
+	      ("The string \"%s\" has been replaced by \"%s\"...",
+	       SearchPrefs -> StringToSearch, ReplaceString);
+	  else
+	    msg = g_strdup_printf
+	      ("%d \"%s\" strings have been replaced by \"%s\"...",
+	       rep_nb, SearchPrefs -> StringToSearch, ReplaceString);
+	  print_msg (msg);
+	  g_free (msg);
+	}
+      else if (SearchPrefs -> RepAll)
 	{
 	  gchar *msg;
 	  gint rep_nb;
@@ -466,6 +511,7 @@ void search (gboolean Replace)
       gtk_window_set_title (GTK_WINDOW(SearchWindow),
 			    "Search and Replace Text");
       SearchPrefs -> RepAll = FALSE;
+      SearchPrefs -> RepAllBuffers = FALSE;
     }
   else
     {
@@ -516,6 +562,10 @@ void search (gboolean Replace)
       gtk_signal_connect (GTK_OBJECT(Button), "toggled",
 			  (GtkSignalFunc)refresh_search, "rep_all");
       gtk_box_pack_start (GTK_BOX(VBox2), Button, FALSE, FALSE, 0);
+      Button = gtk_check_button_new_with_label ("Replace all in every buffer");
+      gtk_signal_connect (GTK_OBJECT(Button), "toggled",
+			  (GtkSignalFunc)refresh_search, "rep_all_buffers");
+      gtk_box_pack_start (GTK_BOX(VBox2), Button, FALSE, FALSE, 0);
       Button = gtk_button_new_with_label (" Replace ");
       gtk_signal_connect (GTK_OBJECT(Button), "clicked",
 			  (GtkSignalFunc)refresh_search, "replace");
